# Author: Koushik Sen (ksen@berkeley.edu)
# Contributors:
# Koushik Sen (ksen@berkeley.edu)
# add your name here

"""Simple RAG system for retrieval-augmented generation."""

from kiss.rag.simple_rag import SimpleRAG

__all__ = ["SimpleRAG"]
